/* This program uses high-frequency data to estimate the asymmetric effect of
   unanticipated changes in the unconventional stance of monetary policy
   on FX portfolio returns, where portfolios are based on credit risk of
   dollar-denominated sovereign bonds.
   NOTE:
   (1) Weighted (average) portfolio FX returns:
         - D#LFX_SG = #-day log-change in speculative-grade FX portfolio
         - D#LFX_IG = #-day log-change in the investment-grade FX portfolio
   (2) # = 2, 6 days
   (3) Monetary policy shocks: DTREAS02Y_W1_POS and DTREAS02Y_W1_NEG 
       NOTE: _W1 denotes intraday change in the wide (60-minute) window
             bracketing an FOMC announcement.
   (4) Sample period: 25Nov2008--16Dec2015 (unconventional policy period)
   (5) Estimation method: OLS w/ robust standard errors
   (6) Results reported in Tables 7 and 8
*/


	/* Set options: */
        #delimit;
	set more off;
	set linesize 255;
	capture log close; 
        mata: mata set matafavor speed;

        /* Output file: */
	capture log using "DFX-CR-F1-asyUP.log", replace; 

	/* Read-in the data: */
	use "fx_wportfolio_cr.dta", clear;


        /* Sample period: */
        keep if date >= mdy(11,25,2008) & date <= mdy(12,16,2015) & (fomc == 1 | lsap == 1 | up_communication == 1);

       /* Positive/negative shocks: */
       gen dtreas02y_w1_pos = 0;
       gen dtreas02y_w1_neg = 0;
       replace dtreas02y_w1_pos = dtreas02y_w1 if dtreas02y_w1 >= 0;
       replace dtreas02y_w1_neg = dtreas02y_w1 if dtreas02y_w1 < 0;


       /****************************************************************************/

       /* Speculative-grade FX portfolio:
          NOTE: 2-day changes bracketing policy announcements. */
       reg d2lfx_sg dtreas02y_w1_pos dtreas02y_w1_neg, r;
       fitstat;

       /* Test the asymmetry: */
       test dtreas02y_w1_pos = dtreas02y_w1_neg;

       /* Test of the normality of residuals: */
       predict double _r, residuals;
       omninorm _r;
       drop _r;

       /* Investment-grade FX portfolio:
          NOTE: 2-day changes bracketing policy announcements. */
       reg d2lfx_ig dtreas02y_w1_pos dtreas02y_w1_neg, r;
       fitstat;

       /* Test the asymmetry: */
       test dtreas02y_w1_pos = dtreas02y_w1_neg;

       /* Test of the normality of residuals: */
       predict double _r, residuals;
       omninorm _r;
       drop _r;



       /* Speculative-grade FX portfolio:
          NOTE: 6-day changes bracketing policy announcements. */
       reg d6lfx_sg dtreas02y_w1_pos dtreas02y_w1_neg, r;
       fitstat;

       /* Test the asymmetry: */
       test dtreas02y_w1_pos = dtreas02y_w1_neg;

       /* Test of the normality of residuals: */
       predict double _r, residuals;
       omninorm _r;
       drop _r;

       /* Investment-grade FX portfolio:
          NOTE: 6-day changes bracketing policy announcements. */
       reg d6lfx_ig dtreas02y_w1_pos dtreas02y_w1_neg, r;
       fitstat;

       /* Test the asymmetry: */
       test dtreas02y_w1_pos = dtreas02y_w1_neg;

       /* Test of the normality of residuals: */
       predict double _r, residuals;
       omninorm _r;
       drop _r;
