/* This program uses high-frequency data to estimate the effect of the
   unanticipated changes in the unconventional stance of monetary policy
   on credit spreads of dollar-denominated sovereign bonds.
   NOTE:
   (1) Weighted portfolio credit spreads:
         - D#YTM_SG = #-day change in speculative-grade sovereign yields
         - D#YTM_IG = #-day change in the investment-grade sovereign yields
   (2) Auxilliary equations:
         - D#YTM_RF_SG = #-day change in comparable maturity Treasury yields
         - D#YTM_RF_IG = #-day change in comparable maturity Treasury yields
   (3) # = 2, 6 days
   (4) Monetary policy shock: DTREAS02Y_W1
       NOTE: _W1 denotes intraday change in the wide (60-minute) window
             bracketing an FOMC announcement.
   (5) Sample period: 25Nov2008--16Dec2015 (unconventional policy period)
   (6) Estimation method: System LS w/ robust standard errors
   (7) Results reported in Tables 4 and 5
*/


	/* Set options: */
        #delimit;
	set more off;
	set linesize 255;
	capture log close; 
        mata: mata set matafavor speed;

        /* Output file: */
	capture log using "DSPR-CR-F1-UP.log", replace; 

	/* Read-in the data: */
	use "bond_wportfolio_cr.dta", clear;


        /* Sample period: */
        keep if date >= mdy(11,25,2008) & date <= mdy(12,16,2015) & (fomc == 1 | lsap == 1 | up_communication == 1);


       /****************************************************************************/

       /* System LS estimation (speculative- and investment-grade bonds):
          NOTE: 2-day changes bracketing policy announcements. */
  
       nlsur (d2ytm_sg = {c_ssg=0} + {b1_ssg=1}*dtreas02y_w1) 
             (d2ytm_ig = {c_sig=0} + {b1_sig=1}*dtreas02y_w1) 
             (d2ytm_rf_sg = {c_tsg=0} + {b1_tsg=1}*dtreas02y_w1 )
             (d2ytm_rf_ig = {c_tig=0} + {b1_tig=1}*dtreas02y_w1),
             nls vce(robust)
             title("The Impact of Monetary Policy on Sovereign Bond Yields")
             title2("(Unconventional Policy Regime / 2-day changes)");

        /* The impact of a shock to TREAS02Y on sovereign credit spreads: */
        /* Speculative grade: */
        lincom [b1_ssg]:_cons - [b1_tsg]:_cons;
        /* Investment grade: */
        lincom [b1_sig]:_cons - [b1_tig]:_cons;

        /* Test of the multivariate normality of residuals: */
        predict double _r1, equation(#1) residuals;
        predict double _r2, equation(#2) residuals;
        predict double _r3, equation(#3) residuals;
        predict double _r4, equation(#4) residuals;

        omninorm _r1 _r2 _r3 _r4;
        drop _r*;


       /* System LS estimation (speculative- and investment-grade bonds):
          NOTE: 6-day changes bracketing policy announcements. */
  
       nlsur (d6ytm_sg = {c_ssg=0} + {b1_ssg=1}*dtreas02y_w1) 
             (d6ytm_ig = {c_sig=0} + {b1_sig=1}*dtreas02y_w1) 
             (d6ytm_rf_sg = {c_tsg=0} + {b1_tsg=1}*dtreas02y_w1 )
             (d6ytm_rf_ig = {c_tig=0} + {b1_tig=1}*dtreas02y_w1),
             nls vce(robust)
             title("The Impact of Monetary Policy on Sovereign Bond Yields")
             title2("(Unconventional Policy Regime / 6-day changes)");

        /* The impact of a shock to TREAS02Y on sovereign credit spreads: */
        /* Speculative grade: */
        lincom [b1_ssg]:_cons - [b1_tsg]:_cons;
        /* Investment grade: */
        lincom [b1_sig]:_cons - [b1_tig]:_cons;

        /* Test of the multivariate normality of residuals: */
        predict double _r1, equation(#1) residuals;
        predict double _r2, equation(#2) residuals;
        predict double _r3, equation(#3) residuals;
        predict double _r4, equation(#4) residuals;

        omninorm _r1 _r2 _r3 _r4;
        drop _r*;
