/* This program uses high-frequency data to estimate the asymmetric effects
   of unanticipated changes in the conventional stance of monetary policy
   on credit spreads of dollar-denominated sovereign bonds.
   NOTE:
   (1) Weighted portfolio credit spreads:
         - D#YTM_SG = #-day change in speculative-grade sovereign yields
         - D#YTM_IG = #-day change in the investment-grade sovereign yields
   (2) Auxilliary equations:
         - D#YTM_RF_SG = #-day change in comparable maturity Treasury yields
         - D#YTM_RF_IG = #-day change in comparable maturity Treasury yields
   (3) # = 2, 6 days
   (4) Monetary policy shocks: DTREAS02Y_N_POS and DTREAS02Y_N_NEG 
       NOTE: _N denotes intraday change in the narrow (30-minute) window
             bracketing an FOMC announcement.
   (5) Sample period: 06Feb1992--24Nov2008 and and 17Dec2015--20Mar2019
                      (conventional policy period)
   (6) Estimation method: System LS w/ robust standard errors
   (7) Results reported in Tables 7 and 8
*/


	/* Set options: */
        #delimit;
	set more off;
	set linesize 255;
	capture log close; 
        mata: mata set matafavor speed;

        /* Output file: */
	capture log using "DSPR-CR-F1-asyCP.log", replace; 

	/* Read-in the data: */
	use "bond_wportfolio_cr.dta", clear;


        /* Sample period: */
        keep if ((date <= mdy(11,24,2008) & d9_11 == 0 & fomc == 1) | (date > mdy(12,17,2015) & fomc == 1));


       /* Positive/negative shocks: */
       gen dtreas02y_n_pos = 0;
       gen dtreas02y_n_neg = 0;
       replace dtreas02y_n_pos = dtreas02y_n if dtreas02y_n >= 0;
       replace dtreas02y_n_neg = dtreas02y_n if dtreas02y_n < 0;
                 

       /****************************************************************************/

       /* System LS estimation (speculative- and investment-grade bonds):
          NOTE: 2-day changes bracketing policy announcements. */
  
       nlsur (d2ytm_sg = {c_ssg=0} + {b1_ssg_p=1}*dtreas02y_n_pos + {b1_ssg_n=1}*dtreas02y_n_neg) 
             (d2ytm_ig = {c_sig=0} + {b1_sig_p=1}*dtreas02y_n_pos + {b1_sig_n=1}*dtreas02y_n_neg) 
             (d2ytm_rf_sg = {c_tsg=0} + {b1_tsg_p=1}*dtreas02y_n_pos + {b1_tsg_n=1}*dtreas02y_n_neg)
             (d2ytm_rf_ig = {c_tig=0} + {b1_tig_p=1}*dtreas02y_n_pos + {b1_tig_n=1}*dtreas02y_n_neg),
             nls vce(robust)
             title("The Asymmetric Impact of Monetary Policy on Sovereign Bond Yields")
             title2("(Conventional Policy Regime / 2-day changes)");

        /* The impact of a positive shock to TREAS02Y on sovereign credit spreads: */
        /* Speculative grade: */
        lincom [b1_ssg_p]:_cons - [b1_tsg_p]:_cons;
        /* Investment grade: */
        lincom [b1_sig_p]:_cons - [b1_tig_p]:_cons;

        /* The impact of a negative shock to TREAS02Y on sovereign credit spreads: */
        /* Speculative grade: */
        lincom [b1_ssg_n]:_cons - [b1_tsg_n]:_cons;
        /* Investment grade: */
        lincom [b1_sig_n]:_cons - [b1_tig_n]:_cons;

        /* Test of the multivariate normality of residuals: */
        predict double _r1, equation(#1) residuals;
        predict double _r2, equation(#2) residuals;
        predict double _r3, equation(#3) residuals;
        predict double _r4, equation(#4) residuals;

        omninorm _r1 _r2 _r3 _r4;
        drop _r*;


       /* System LS estimation (speculative- and investment-grade bonds):
          NOTE: 6-day changes bracketing policy announcements. */
  
       nlsur (d6ytm_sg = {c_ssg=0} + {b1_ssg_p=1}*dtreas02y_n_pos + {b1_ssg_n=1}*dtreas02y_n_neg) 
             (d6ytm_ig = {c_sig=0} + {b1_sig_p=1}*dtreas02y_n_pos + {b1_sig_n=1}*dtreas02y_n_neg) 
             (d6ytm_rf_sg = {c_tsg=0} + {b1_tsg_p=1}*dtreas02y_n_pos + {b1_tsg_n=1}*dtreas02y_n_neg)
             (d6ytm_rf_ig = {c_tig=0} + {b1_tig_p=1}*dtreas02y_n_pos + {b1_tig_n=1}*dtreas02y_n_neg),
             nls vce(robust)
             title("The Asymmetric Impact of Monetary Policy on Sovereign Bond Yields")
             title2("(Conventional Policy Regime / 6-day changes)");

        /* The impact of a positive shock to TREAS02Y on sovereign credit spreads: */
        /* Speculative grade: */
        lincom [b1_ssg_p]:_cons - [b1_tsg_p]:_cons;
        /* Investment grade: */
        lincom [b1_sig_p]:_cons - [b1_tig_p]:_cons;

        /* The impact of a negative shock to TREAS02Y on sovereign credit spreads: */
        /* Speculative grade: */
        lincom [b1_ssg_n]:_cons - [b1_tsg_n]:_cons;
        /* Investment grade: */
        lincom [b1_sig_n]:_cons - [b1_tig_n]:_cons;

        /* Test of the multivariate normality of residuals: */
        predict double _r1, equation(#1) residuals;
        predict double _r2, equation(#2) residuals;
        predict double _r3, equation(#3) residuals;
        predict double _r4, equation(#4) residuals;

        omninorm _r1 _r2 _r3 _r4;
        drop _r*;
